@@ -1,18 +1,18 @@
 #!/usr/bin/env bash
 
-# Synchs the release-next branch to master and then triggers CI
+# Synchs the release-next branch to main and then triggers CI
 # Usage: update-to-head.sh
 
 set -e
 REPO_NAME=`basename $(git rev-parse --show-toplevel)`
 
-# Reset release-next to upstream/master.
-git fetch upstream master
-git checkout upstream/master -B release-next
+# Reset release-next to upstream/main.
+git fetch upstream main
+git checkout upstream/main -B release-next
 
-# Update openshift's master and take all needed files from there.
-git fetch openshift master
-git checkout openshift/master openshift OWNERS_ALIASES OWNERS Makefile
+# Update openshift's main and take all needed files from there.
+git fetch openshift main
+git checkout openshift/main openshift OWNERS_ALIASES OWNERS Makefile
 make generate-dockerfiles
 make RELEASE=ci generate-release
 git add openshift OWNERS_ALIASES OWNERS Makefile
@@ -20,8 +20,6 @@ git commit -m ":open_file_folder: Update openshift specific files."
 
 # Apply patches .
 git apply openshift/patches/*
-# TODO: enable autoscaler HA test once https://github.com/knative/operator/issues/337 was solved.
-rm test/ha/autoscaler_test.go
 git commit -am ":fire: Apply carried patches."
 
 git push -f openshift release-next
@@ -30,7 +28,7 @@ git push -f openshift release-next
 git checkout release-next -B release-next-ci
 date > ci
 git add ci
-git commit -m ":robot: Triggering CI on branch 'release-next' after synching to upstream/master"
+git commit -m ":robot: Triggering CI on branch 'release-next' after synching to upstream/main"
 git push -f openshift release-next-ci
 
 if hash hub 2>/dev/null; then
